@@ -36,10 +36,7 @@ sub out_gdl
     {
         $glyph = $self->{'glyphs'}[$i];
         $fh->print("$glyph->{'name'} = ");
-        if ($opts{'-psnames'} && $glyph->{'post'} && $glyph->{'post'} ne '.notdef')
-        { $fh->print("postscript(\"$glyph->{'post'}\")"); }
-        else
-        { $fh->print("glyphid($i)"); }
+        $fh->print("glyphid($i)");
 
         my ($ytop) = $f->{'hhea'}->read->{'Ascender'};
         my ($adv) = $f->{'hmtx'}->read->{'advance'}[$i];
@@ -55,16 +52,16 @@ sub out_gdl
 
                 if ($opts{'-split_ligs'})
                 {
-                    if (defined $glyph->{'compunds'}{$pl})
-                    { $glyph->{'compounds'}{$pl}[3] = $pt->{'x'}; }
+                    if (defined $glyph->{'comps'}{$pl})
+                    { $glyph->{'comps'}{$pl}[3] = $pt->{'x'}; }
                     else
-                    { $glyph->{'compounds'}{$pl} = [0, 0, $pt->{'x'}, $ytop]; }
+                    { $glyph->{'comps'}{$pl} = [0, 0, $pt->{'x'}, $ytop]; }
                     if ($pr)
                     {
-                        if (defined $glyph->{'compounds'}{$pr})
-                        { $glyph->{'compounds'}{$pr}[0] = $pt->{'x'}; }
+                        if (defined $glyph->{'comps'}{$pr})
+                        { $glyph->{'comps'}{$pr}[0] = $pt->{'x'}; }
                         else
-                        { $glyph->{'compounds'}{$pr} = [$pt->{'x'}, 0, $adv, $ytop]; }
+                        { $glyph->{'comps'}{$pr} = [$pt->{'x'}, 0, $adv, $ytop]; }
                     }
                 }
                 next;
@@ -85,27 +82,27 @@ sub out_gdl
             {
                 my ($n) = $k;
                 $n =~ s/^component\.//o;
-                $glyph->{'compounds'}{$n} = [0, 0, $glyph->{'props'}{$k}, $ytop];
+                $glyph->{'comps'}{$n} = [0, 0, $glyph->{'props'}{$k}, $ytop];
             }
-            foreach $k (sort {$glyph->{'compounds'}{$a}[2] <=> $glyph->{'compounds'}{$b}[2]} keys %{$glyph->{'compounds'}})
+            foreach $k (sort {$glyph->{'comps'}{$a}[2] <=> $glyph->{'comps'}{$b}[2]} keys %{$glyph->{'comps'}})
             {
-                $glyph->{'compounds'}{$k} = [$oldx, 0, $glyph->{'compounds'}{$k}[2], $glyph->{'compounds'}{$k}[3]];
-                $oldx = $glyph->{'compounds'}{$k}[2];
+                $glyph->{'comps'}{$k} = [$oldx, 0, $glyph->{'comps'}{$k}[2], $glyph->{'comps'}{$k}[3]];
+                $oldx = $glyph->{'comps'}{$k}[2];
                 $min = $k if ($k > $min);
             }
-            if (scalar %{$glyph->{'compounds'}} && $oldx < $adv)
+            if (scalar %{$glyph->{'comps'}} && $oldx < $adv)
             {
                 my ($maxx) = $f->{'loca'}->read->{'glyphs'}[$i]{'xMax'};
                 if ($oldx < $maxx)          # only add magic compound if some outline not covered
                 {
                     $min++;
-                    $glyph->{'compounds'}{$min} = [$oldx, 0, $adv, $ytop];
+                    $glyph->{'comps'}{$min} = [$oldx, 0, $adv, $ytop];
                 }
             }
         }
-        foreach $k (keys %{$glyph->{'compounds'}})
+        foreach $k (keys %{$glyph->{'comps'}})
         {
-            $fh->print("${sep}component.$k = box(" . join(", ", map {"${_}m"} @{$glyph->{'compounds'}{$k}}) . ")");
+            $fh->print("${sep}component.$k = box(" . join(", ", map {"${_}m"} @{$glyph->{'comps'}{$k}}) . ")");
             $sep = '; ';
         }
         foreach $k (keys %{$glyph->{'props'}})
@@ -175,7 +172,7 @@ sub out_classes
     }
 
 
-    foreach $cl (sort {classcmp($a, $b)} keys %{$classes})
+    foreach $cl (sort keys %{$classes})
     {
         $fh->print("c$cl = ($glyphs->[$classes->{$cl}[0]]{'name'}");
         for ($i = 1; $i <= $#{$classes->{$cl}}; $i++)
@@ -183,9 +180,9 @@ sub out_classes
         $fh->print(");\n\n");
     }
 
-    foreach $cl (sort {classcmp($a, $b)} keys %{$ligclasses})
+    foreach $cl (sort keys %{$ligclasses})
     {
-        $fh->print("clig$cl = ($glyphs->[$ligclasses->{$cl}[0]]{'name'}");
+        $fh->print("cl$cl = ($glyphs->[$ligclasses->{$cl}[0]]{'name'}");
         for ($i = 1; $i <= $#{$ligclasses->{$cl}}; $i++)
         { $fh->print($i % 8 ? ", $glyphs->[$ligclasses->{$cl}[$i]]{'name'}" : ",\n    $glyphs->[$ligclasses->{$cl}[$i]]{'name'}"); }
         $fh->print(");\n\n");
@@ -194,15 +191,6 @@ sub out_classes
     $self;
 }
 
-sub classcmp
-{
-    my ($x, $y) = @_;
-    my ($v, $w) = ($x, $y);
-    $v =~ s/^no_//o;
-    $w =~ s/^no_//o;
-    return ($v cmp $w || $x cmp $y);
-}
-
 sub endtable
 {
     my ($self, $fh) = @_;
@@ -222,21 +210,14 @@ sub end_gdl
 sub make_name
 {
     my ($self, $gname, $uni, $glyph) = @_;
-    $gname =~ s/[:\(\)\{\}]//g;
     $gname =~ s{/.*$}{}o;
     $gname =~ s/\.(.)/'_'.lc($1)/oge;
-    if ($gname =~ m/^u(?:[0-9A-Fa-f]{4,6})/oi)
+    if ($gname =~ m/^u(?:ni)?(?:[0-9A-Fa-f]{4,6})/o)
     { 
         $gname = "g" . lc($gname);
-        $gname =~ s/^gu/g/o;
+        $gname =~ s/^gu(?:ni)?/g/o;
         $gname =~ s/_u/_/og;
     }
-    elsif ($gname =~ s/^uni(?=[0-9A-Fa-f]{4})//oi)
-    {
-        my (@nums) = $gname =~ m/([0-9A-Fa-f]{4})/og;
-        $gname =~ s/[0-9A-Fa-f]{4}//og;
-        $gname = 'g' . join('_', map {lc($_)} @nums) . $gname;
-    }
     else
     {
         $gname = "g_" . $gname;
@@ -257,8 +238,8 @@ sub make_point
         my ($adv) = $self->{'font'}{'hmtx'}->read->{'advances'}[$glyph->{'gnum'}];
         my ($split) = $glyph->{'points'}{$p}{'x'};
 
-        $glyph->{'compounds'}{$left} = [0, $bot, $split, $top];
-        $glyph->{'compounds'}{$right} = [$split, $bot, $adv, $top];
+        $glyph->{'comps'}{$left} = [0, $bot, $split, $top];
+        $glyph->{'comps'}{$right} = [$split, $bot, $adv, $top];
         return undef;
     }
 
@@ -267,7 +248,7 @@ sub make_point
 
 sub normal_rules
 {
-    my ($self, $fh, $pnum, $ndrawn) = @_;
+    my ($self, $fh, $pnum) = @_;
     my ($g, $struni, $seq, $dseq, $dcomb, @decomp, $d);
     my ($c) = $self->{'cmap'};
     my ($glyphs) = $self->{'glyphs'};
@@ -275,7 +256,7 @@ sub normal_rules
     $fh->print("\ntable(substitution);\npass($pnum);\n");
     foreach $g (@{$self->{'glyphs'}})
     {
-        next unless ($ndrawn || $g->{'props'}{'drawn'});
+        next unless ($g->{'props'}{'drawn'});
 # TODO: should really handle multiple unicode values correctly
         next unless ($c->{$g->{'uni'}[0]} == $g->{'gnum'});
         $struni = pack('U', $g->{'uni'}[0]);
@@ -287,20 +268,20 @@ sub normal_rules
         { $dok = 0 unless $c->{$d}; }
         next unless $dok;
 
-        $fh->print(join(' ', map {$glyphs->[$c->{$_}]{'name'}} @decomp) . " > $g->{'name'}:(" . join(' ', 1 .. scalar @decomp) . ") " . ("_ " x (scalar @decomp - 1)) . ";\n");
+        $fh->print(join(' ', map {$glyphs->[$c->{$_}]{'name'}} @decomp) . " > $g->{'name'} " . ("_ " x (scalar @decomp - 1)) . ";\n");
 
         if (scalar @decomp > 2)
         {
-            $fh->print(join(' ', map {$glyphs->[$c->{$_}]{'name'}} @decomp[0, 2, 1]) . " > $g->{'name'}:(1 2 3) _ _;\n");
+            $fh->print(join(' ', map {$glyphs->[$c->{$_}]{'name'}} @decomp[0, 2, 1]) . " > $g->{'name'} _ _;\n");
             $dseq = pack('U*', @decomp[0, 1]);
             $dcomb = NFC($dseq);
             if ($dcomb ne $dseq)
-            { $fh->print($glyphs->[$c->{unpack('U', $dcomb)}]{'name'} . " " . $glyphs->[$c->{$decomp[2]}]{'name'} . " > $g->{'name'}:(1 2) _;\n"); }
+            { $fh->print($glyphs->[$c->{unpack('U', $dcomb)}]{'name'} . " " . $glyphs->[$c->{$decomp[2]}]{'name'} . " > $g->{'name'} _;\n"); }
 
             $dseq = pack('U*', @decomp[0, 2]);
             $dcomb = NFC($dseq);
             if ($dcomb ne $dseq)
-            { $fh->print($glyphs->[$c->{unpack('U', $dcomb)}]{'name'} . " " . $glyphs->[$c->{$decomp[1]}]{'name'} . " > $g->{'name'}:(1 2) _;\n"); }
+            { $fh->print($glyphs->[$c->{unpack('U', $dcomb)}]{'name'} . " " . $glyphs->[$c->{$decomp[1]}]{'name'} . " > $g->{'name'} _;\n"); }
         }
     }
     $fh->print("endpass;\nendtable;\n");
@@ -321,39 +302,14 @@ sub lig_rules
         my ($gname) = $self->{'glyphs'}[$gnum]{'name'};
         my ($compstr);
 
-        if ($self->{'glyphs'}[$ligclasses->{$c}[0]]{'compounds'}{'0'})
+        if ($self->{'glyphs'}[$ligclasses->{$c}[0]]{'comps'}{'0'})
         { $compstr = ' {component.0.reference = @1; component.1.reference = @2}'; }
 
         if ($type eq 'first')
-        { $fh->print("$gname cligno_$c > _ clig$c:(1 2)$compstr / _ ^ _;\n"); }
+        { $fh->print("$gname clno_$c > _ cl$c:(1 2)$compstr / _ ^ _;\n"); }
         else
-        { $fh->print("cligno_$c $gname > clig$c:(1 2)$compstr _/ ^ _ _;\n"); }
+        { $fh->print("clno_$c $gname > cl$c:(1 2)$compstr _/ ^ _ _;\n"); }
 
     }
     $fh->print("endpass;\nendtable;\n");
 }
-
-sub pos_rules
-{
-    my ($self, $fh, $pnum) = @_;
-    my ($lists) = $self->{'lists'};
-    my ($p);
-
-    return unless (keys %$lists);
-    $fh->print(<<'EOT');
-
-#ifndef opt2
-#define opt(x)      [x]?
-#define opt2(x)     [opt(x) x]?
-#define opt3(x)     [opt2(x) x]?
-#define opt4(x)     [opt3(x) x]?
-#endif
-EOT
-    $fh->print("\ntable(positioning);\npass($pnum);\n");
-    foreach $p (keys %{$lists})
-    {
-        next if ($p =~ m/^_/o);
-        $fh->print("cTakes${p}Dia c${p}Dia {attach {to = \@1; at = ${p}S; with = ${p}M}; user1 = 1} / ^ _ opt4(cnTakes${p}Dia) _ {user1 == 0};\n");
-    }
-    $fh->print("endpass;\nendtable;\n");
-}
